@@ -1,7 +1,7 @@
 <?
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: confgen.php,v 1.6 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: confgen.php,v 1.7 2004/03/11 17:24:21 lukasz Exp $
  */
 
 // zacznijmy od budowania listy hostw:
@@ -31,7 +31,6 @@ if($_GET['tpl'] == '')
 	$layout['pagetitle'] = 'Pliki konfiguracyjne';
 	$templateslist = $LMS->GetTemplatesList();
 	$SMARTY->assign('templateslist',$templateslist);
-	$SMARTY->assign('layout',$layout);
 	$SMARTY->display('confgen.html');
 }
 else
