@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,12 +21,11 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: copyrights.php,v 1.19 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: copyrights.php,v 1.20 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Informacje o prawach autorskich";
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('header.html');
 $SMARTY->display('copyrights.html');
 $SMARTY->display('footer.html');
