@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,30 +21,29 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netcmp.php,v 1.19 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: netcmp.php,v 1.21 2004/03/11 17:24:22 lukasz Exp $
  */
 
-if(!$LMS->NetworkExists($_GET[id]))
+if(!$LMS->NetworkExists($_GET['id']))
 {
 	header("Location: ?m=netlist");
 	die;
 }
 
-$network[name] = $LMS->GetNetworkName($_GET[id]);
+$network['name'] = $LMS->GetNetworkName($_GET['id']);
 
-if($_GET[is_sure])
+if($_GET['is_sure'])
 {
-	$LMS->NetworkCompress($_GET[id]);
-	header("Location: ?m=".$_SESSION[lastmodule]."&id=".$_GET[id]);
+	$LMS->NetworkCompress($_GET['id']);
+	header("Location: ?m=".$_SESSION['lastmodule']."&id=".$_GET['id']);
 	die;
 }else{
-	$layout[pagetitle]="Porzdkowanie sieci ".strtoupper($network[name]);
-	$SMARTY->assign("layout",$layout);
-	$SMARTY->display("header.html");
-	echo "<H1>Porzdkowanie sieci ".strtoupper($network[name])."</H1>";
+	$layout['pagetitle'] = "Porzdkowanie sieci ".strtoupper($network['name']);
+	$SMARTY->display('header.html');
+	echo "<H1>Porzdkowanie sieci ".strtoupper($network['name'])."</H1>";
 	echo "<p>Czy jeste pewien e chcesz uporzdkowa t sie?</p>";
-	echo "<a href=\"?m=netcmp&id=".$_GET[id]."&is_sure=1\">Tak, jestem pewien</A>";
-	$SMARTY->display("footer.html");
+	echo "<a href=\"?m=netcmp&id=".$_GET['id']."&is_sure=1\">Tak, jestem pewien</A>";
+	$SMARTY->display('footer.html');
 }
 
 ?>
\ No newline at end of file
