@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.14 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netdevmap.php,v 1.15 2004/03/11 17:24:22 lukasz Exp $
 
                                  _
  _   ___      ____ _  __ _  __ _| |
@@ -133,7 +133,6 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 }
 
 $layout['pagetitle'] = "Mapa pocze sieciowych";
-$SMARTY->assign('layout',$layout);
 
 if($_GET['graph'] == "")
 {
