@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netlist.php,v 1.24 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netlist.php,v 1.25 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Sieci IP";
@@ -37,7 +37,6 @@ $listdata['total'] = sizeof($netlist);
 
 $SMARTY->assign('listdata',$listdata);
 $SMARTY->assign('netadd',$netadd);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('netlist',$netlist);
 $SMARTY->display('netlist.html');
 
