@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeinfo.php,v 1.30 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: nodeinfo.php,v 1.31 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(!eregi("^[0-9]+$",$_GET['id']))
@@ -78,7 +78,6 @@ $SMARTY->assign('userinfo',$userinfo);
 $SMARTY->assign('nodeinfo',$nodeinfo);
 $SMARTY->assign('assignments',$assignments);
 $SMARTY->assign('tariffs',$tariffs);
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('nodeinfo.html');
 
 ?>
