@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: useredit.php,v 1.56 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: useredit.php,v 1.61 2004/03/30 16:43:58 alec Exp $
  */
 
 $userdata = $_POST['userdata'];
@@ -99,9 +99,37 @@ elseif($_GET['action'] == 'addassignment')
 		break;
 	}
 
+	if(trim($_POST['datefrom'] == ''))
+		$from = 0;
+	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',trim($_POST['datefrom'])))
+	{
+		list($y, $m, $d) = split('/', trim($_POST['datefrom']));
+		if(checkdate($m, $d, $y))
+			$from = mktime(0, 0, 0, $m, $d, $y);
+		else
+			$error[] = 'Koniec okresu naliczania jest niepoprawny!';
+	}
+	else
+		$error[] = 'Pocztek okresu naliczania jest niepoprawny!';
+
+	if(trim($_POST['dateto'] == ''))
+		$to = 0;
+	elseif(eregi('^[0-9]{4}/[0-9]{2}/[0-9]{2}$',trim($_POST['dateto'])))
+	{
+		list($y, $m, $d) = split('/', trim($_POST['dateto']));
+		if(checkdate($m, $d, $y))
+			$to = mktime(23, 59, 59, $m, $d, $y);
+		else
+			$error[] = 'Koniec okresu naliczania jest niepoprawny!';
+	}
+	else
+		$error[] = 'Koniec okresu naliczania jest niepoprawny!';
+
+	if($to < $from && $to != 0 && $from != 0)
+		$error[] = 'Zakres dat jest niepoprawny!';
+
 	if($LMS->TariffExists($_POST['tariffid']) && !$error)
-		$LMS->AddAssignment(array('tariffid' => $_POST['tariffid'], 'userid' => $_GET['id'], 'period' => $period, 'at' => $at, 'invoice' => sprintf('%d',$_POST['invoice'])));
-		
+		$LMS->AddAssignment(array('tariffid' => $_POST['tariffid'], 'userid' => $_GET['id'], 'period' => $period, 'at' => $at, 'invoice' => sprintf('%d',$_POST['invoice']), 'datefrom' => $from, 'dateto' => $to ));
 	header('Location: ?m=userinfo&id='.$_GET['id']);
 	die;
 			
@@ -166,7 +194,6 @@ $SMARTY->assign('balancelist',$LMS->GetUserBalanceList($userinfo['id']));
 $SMARTY->assign('tariffs',$LMS->GetTariffs());
 $SMARTY->assign('assignments',$LMS->GetUserAssignments($_GET['id']));
 $SMARTY->assign('userinfo',$userinfo);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('recover',($_GET['action'] == 'recover' ? 1 : 0));
 $SMARTY->display('useredit.html');
 
