@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3-cvs
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userlist.php,v 1.37 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: userlist.php,v 1.39 2004/03/26 09:05:35 alec Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
@@ -40,13 +40,19 @@ else
 	$s = $_GET['s'];
 $_SESSION['uls'] = $s;
 
+if(!isset($_GET['n']))
+	$n = $_SESSION['uln'];
+else
+	$n = $_GET['n'];
+$_SESSION['uln'] = $n;
+
 if (isset($_SESSION['ulp']) && !isset($_GET['page']))
 	$_GET['page'] = $_SESSION['ulp'];
 	    
-
-$userlist=$LMS->GetUserList($o,$s);
+$userlist=$LMS->GetUserList($o, $s, $n);
 $listdata['total'] = $userlist['total'];
 $listdata['state'] = $userlist['state'];
+$listdata['network'] = $userlist['network'];
 $listdata['order'] = $userlist['order'];
 $listdata['below'] = $userlist['below'];
 $listdata['over'] = $userlist['over'];
@@ -60,13 +66,14 @@ $_SESSION['ulp'] = $page;
 
 unset($userlist['total']);
 unset($userlist['state']);
+unset($userlist['network']);
 unset($userlist['order']);
 unset($userlist['below']);
 unset($userlist['over']);
 unset($userlist['direction']);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('userlist',$userlist);
 $SMARTY->assign('listdata',$listdata);
+$SMARTY->assign('networks', $LMS->GetNetworks());
 $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('start',$start);
